@@ -9,7 +9,7 @@
 /*  CCOPYRIGHT */
 
 /****************************************************************************
-** $Id: application.cpp,v 1.143.4.2 2007/08/12 17:08:43 flitney Exp $
+** $Id: application.cpp,v 1.146.2.2 2009/05/27 16:52:28 flitney Exp $
 **
 ** Copyright (C) 2002 University of Oxford.  All rights reserved.
 **
@@ -61,6 +61,16 @@
 
 #include "modelfit.h"
 
+#include <algorithm>
+#include <functional>
+#include <boost/bind.hpp>
+
+
+bool ComparePaths(const Image::Handle im1, const Image::Handle im2)
+{
+  return (im1->getInfo()->inqFileName() == im2->getInfo()->inqFileName());
+}
+
 // // Concrete command class for FileOpen menu item
 // class FileOpen : public Command
 // {
@@ -97,8 +107,11 @@
 // const char * fileOpenText = "Click this button to open a <em>folder</em>.<br><hr>"
 // "You can also select the <b>Open command</b> from the File menu.";
 
-ApplicationWindow::ApplicationWindow(const OverlayOptionList& overlays)
-  : ApplicationWindowBase( 0, "FslView", WDestructiveClose ), m_properties(Properties::create()), m_toolbarMenuId(0)
+ApplicationWindow::ApplicationWindow(ApplicationOptions& options):
+  ApplicationWindowBase( 0, "FslView", WDestructiveClose ), 
+  m_properties(Properties::create()), 
+  m_toolbarMenuId(0),
+  m_options(options)
 {  
   TRACKER("ApplicationWindow::ApplicationWindow");
   qApp->setMainWidget(this);
@@ -111,18 +124,8 @@ ApplicationWindow::ApplicationWindow(const OverlayOptionList& overlays)
   int dw(QApplication::desktop()->width());
   int dh(QApplication::desktop()->height());
 
-  int x(0), y(0), w(0), h(0);
-  if(dh <= 800) {
-    h = (dh * 85) / 100;
-    w = (dw * 85) / 100;
-    x = (dw - w)/2;
-    y = (dh - h)/2;
-  } else {
-    h = (dh * 90) / 100;
-    w = (h  * 80) / 100;
-    x = y = (dh * 5) / 100;
-  }
-  setGeometry( x, y, w, h );
+  setMinimumSize(200,200);
+  setGeometry(Preferences::getInstance()->inqGeometry(dw, dh));
 
   setupStatusBar(); 
 
@@ -144,9 +147,9 @@ ApplicationWindow::ApplicationWindow(const OverlayOptionList& overlays)
     FslSetOverrideOutputType(FSL_TYPE_ANALYZE);
   }
   
-  if(!overlays.empty())
+  if(!m_options.empty())
     {
-      OverlayOptionList::const_iterator it = overlays.begin();
+      OverlayOptionList::const_iterator it = m_options.begin();
 
       QString fn(it->fileInfo().absFilePath());
       if( loadFile(fn) ) {
@@ -156,30 +159,92 @@ ApplicationWindow::ApplicationWindow(const OverlayOptionList& overlays)
 
 	if( ModelFit::isFeatDir(fn) )
 	  loadFeat(fn);
+
 	if(it->lutSpecified())
-	  ds->setLookUpTable(m_imageGroup->getLut(it->lutname()));
+	  ol->setLookUpTable(m_imageGroup->getLut(it->lutname()));
+	if(it->transparencySpecified())
+	  ol->setTransparency(it->transparency());
 	if(it->briconSpecified())
 	  ds->inqBriCon()->setRange(it->min(), it->max());
 
-	while(++it != overlays.end())
+	while(++it != m_options.end())
 	  {
 	    loadOverlay(it->fileInfo().absFilePath());
 
 	    ImageDisplaySetting::Handle ds = ol->getActiveMetaImage()->getDs();
 
 	    if(it->lutSpecified())
-	      ds->setLookUpTable(m_imageGroup->getLut(it->lutname()));
+	      ol->setLookUpTable(m_imageGroup->getLut(it->lutname()));
+	    if(it->transparencySpecified())
+	      ol->setTransparency(it->transparency());
 	    if(it->briconSpecified())
 	      ds->inqBriCon()->setRange(it->min(), it->max());
 	  }
 
-	setCurrentDir(overlays.begin()->fileInfo().absFilePath());
+	if(m_modelFit) {
+	  Image::Handle image = m_modelFit->getFilteredFuncImage();
+
+	  // Need to add this image iff not already in image group
+	  ImageGroup::ImageList::iterator it = 
+	    std::find_if( m_imageGroup->begin(), m_imageGroup->end(),
+			  boost::bind(ComparePaths, _1, image) );
+      
+	  if( it ==  m_imageGroup->end() ) {
+	    m_imageGroup->addOverlay(image);
+	    activeOverlayList()->setVisibility(false);
+	  }
+	}
+
+	std::list<ApplicationOptions::Mode> modes = m_options.inqModes();
+	if(modes.size()) {
+	  while(!modes.empty()) {
+	    switch(modes.front()) {
+	    case ApplicationOptions::Ortho :
+	      viewOrthographic();
+	      break;
+	    case ApplicationOptions::Lightbox :
+	      viewLightbox();
+	      break;
+	    case ApplicationOptions::Single :
+	      viewSingle();
+	      break;
+	    case ApplicationOptions::ThreeD :
+	      view3d();
+	      break;
+	    default:
+	      break;
+	    }
+	    modes.pop_front();
+	  }
+	} else
+	  viewOrthographic();
+	
+	if(m_modelFit) {
+	  Image::Handle image = m_modelFit->getFilteredFuncImage();
+	  // And display it as a timeseries with model viewing capabilities
+	  TimeSeriesWidget* timeseries = new TimeSeriesWidget(m_ws, image, m_cursor, m_modelFit);
+	  connect( timeseries, SIGNAL(windowClose(QCloseEvent*)), 
+		   this, SLOT(childWindowClose(QCloseEvent*)));
+	  timeseries->setCaption("Feat data");
+	  timeseries->resize(250,250);
+	  viewShow(timeseries);
+	}
+    
+	/*
+	 * set menu items to appropriate states after image has been 
+	 * loaded, as they were set to some
+	 * states, initially, when no images were loaded
+	 */
+	setFileMenuItemsState();
+	setViewMenuItemsState();
+
+	setCurrentDir(m_options.begin()->fileInfo().absFilePath());      
       } else
-	QMessageBox::warning( this, "FSLView",
- 			      "Failed to load base image. Command line processing aborted." );
+	QMessageBox::warning( this, "FSLView", "Failed to load base image. Command line processing aborted." );
     }
 }
 
+
 void ApplicationWindow::assistantError(const QString& msg)
 {
   QMessageBox::warning(this, "FSLView - error while invoking help client", msg);
@@ -193,8 +258,8 @@ ApplicationWindow::~ApplicationWindow()
 
 //! @brief load an image file
 //!
-//! This method is used to load a given file into the application. It can be called
-//! from event handlers as well as directly from client code.
+//! This method is used to load a given file into the application. 
+//! It can be called from event handlers as well as directly from client code.
 //! 
 //! @param absFilePath the path to the file to be loaded
 //!
@@ -203,36 +268,27 @@ bool ApplicationWindow::loadFile(const QString & absFilePath)
 { 
   bool status(true);
 
-  QString fn(absFilePath);
-  QFileInfo fi(absFilePath);
+  try {
+    QString fn(absFilePath);
+    QFileInfo fi(absFilePath);
 
-  removeExtensions(fn);
+    removeExtensions(fn);
 
-  try
-  {
     if ( !fn.isEmpty() && checkFilesExist(fn,false))
     {
-      emit message(QString("Loading.... %1").arg(fn), -1);  
-      // display message before file is loaded. -1 displays message until the next message
-      // displayed or until the clear() function is called
+      m_masterOverlayList.reset();
+      m_modelFit.reset();
+      m_imageGroup.reset();
 
+      QApplication::setOverrideCursor(Qt::waitCursor);
+      emit message(QString("Loading.... %1").arg(fn), 5000);  
+      qApp->processEvents();
+ 
       m_imageGroup = ImageGroup::create( Image::load((const char *)fn) );
       ImageInfo::Handle info(m_imageGroup->getMainImage()->getInfo());
-      m_cursor = Cursor::create(info->inqX(),
-                                info->inqY(),info->inqZ(), 
+      m_cursor = Cursor::create(info->inqX(),info->inqY(),info->inqZ(), 
                                 info->inqNumVolumes());
 
-      viewOrthographic();
-      /*
-       * set menu items to appropriate states after image has been 
-       * loaded, as they were set to some
-       * states, initially, when no images were loaded
-       */
-      setFileMenuItemsState();
-      setViewMenuItemsState();
-      
-      emit message("Image Loaded", 10000); // display message after file has been loaded
-      
       OverlayList::Handle ol(activeOverlayList());
       Image::Handle im(m_imageGroup->getMainImage());
 
@@ -254,17 +310,15 @@ bool ApplicationWindow::loadFile(const QString & absFilePath)
       m_cursor->setCursor( info->inqX()/2, info->inqY()/2, info->inqZ()/2 ); 
 
       QApplication::restoreOverrideCursor();      
-
+ 
       if(checkForDuplicates(fn))
         {
           QMessageBox::warning(this,"FSLView",
           "Warning: Multiple versions of the image files exist!");
         }
-
       }  
     else 
       {
-	status = false;
         if(!checkFilesExist(fn,false))
           {
 	    QMessageBox::warning( this, "FSLView",
@@ -274,6 +328,7 @@ bool ApplicationWindow::loadFile(const QString & absFilePath)
               {
                 emit message( QString("Missing image file %1").arg(fn), 2000 );
               }
+	    status = false;
           }
         else
           {
@@ -286,7 +341,8 @@ bool ApplicationWindow::loadFile(const QString & absFilePath)
       catchFileError(f);
     }
 
-  setFileMenuItemsState();
+  initFileMenuItems(status);
+  initViewMenuItems(status);
 
   return status;
 }
@@ -314,12 +370,14 @@ void ApplicationWindow::helpAbout()
   QMessageBox::about( this, "FSLView",
 		      QString("<h2>FSLView</h2><hr><b>Version %1.%2</b><br>"
 			      "Written by:"
-			      "<ul><li>Dave Flitney</li>"
+			      "<ul>"
+			      "<li>Dave Flitney</li>"
 			      "<li>James Saunders</li>"
 			      "<li>Mark Jenkinson</li>"
 			      "<li>Steve Smith</li>"
-			      "<li>V Rama Aravind</li></ul><br>"
-			      "Copyright(c) 2004 University of Oxford<br><hr>"
+			      "<li>V Rama Aravind</li>"
+			      "</ul><br>"
+			      "Copyright(c) 2004-2009 University of Oxford<br><hr>"
 			      "<b>Help pages: http://www.fmrib.ox.ac.uk/fsl/fslview</b><hr>"
 			      "Please report  bugs to:<br><b>fslview-bugs@fmrib.ox.ac.uk<b>")
 		      .arg(Version).arg(Release));
@@ -371,9 +429,20 @@ void ApplicationWindow::helpOnlineHelp()
    AssistantClient::getInstance()->showPage( QString("index.html") );
 }
 
+void ApplicationWindow::help3DRendering()
+{
+   AssistantClient::getInstance()->showPage( QString("3D.html") );
+}
+
+void ApplicationWindow::menusUpdate()
+{
+  setFileMenuItemsState();
+  setViewMenuItemsState();
+}
+
 void ApplicationWindow::fileMenuAboutToShow()
 {
-   setFileMenuItemsState();
+  setFileMenuItemsState();
 }
 
 void ApplicationWindow::viewMenuAboutToShow()
@@ -480,20 +549,62 @@ void ApplicationWindow::fileOpen(void)
   QString fn = QFileDialog::getOpenFileName(QDir::currentDirPath(),
 					    "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					    this );
-
   if(!fn.isEmpty()) {
     loadFile(fn);
     if(ModelFit::isFeatDir(fn))
       loadFeat(fn);
     setCurrentDir(fn);
+
+    viewOrthographic();
+
+    if(m_modelFit) {
+      Image::Handle image = m_modelFit->getFilteredFuncImage();
+  
+      // Need to add this image iff not already in image group
+      ImageGroup::ImageList::iterator it = 
+	std::find_if( m_imageGroup->begin(), m_imageGroup->end(),
+		      boost::bind(ComparePaths, _1, image) );
+      
+      if( it ==  m_imageGroup->end() ) {
+	m_imageGroup->addOverlay(image);
+	activeOverlayList()->setVisibility(false);
+      }
+      // And display it as a timeseries with model viewing capabilities      
+      TimeSeriesWidget* timeseries = new TimeSeriesWidget(m_ws, image, m_cursor, m_modelFit);
+      connect( timeseries, SIGNAL(windowClose(QCloseEvent*)), 
+	       this, SLOT(childWindowClose(QCloseEvent*)));
+      timeseries->setCaption("Feat data");
+      timeseries->resize(250,250);
+      viewShow(timeseries);
+    }
+
+    /*
+     * set menu items to appropriate states after image has been 
+     * loaded, as they were set to some
+     * states, initially, when no images were loaded
+     */
+    setFileMenuItemsState();
+    setViewMenuItemsState();
   }
 }
 
 void ApplicationWindow::fileAdd()
 {
   QString fn = QFileDialog::getOpenFileName( QDir::currentDirPath(), "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", this );
-  if(!fn.isEmpty())loadOverlay(fn);
+
   if(!fn.isNull())setCurrentDir(fn);
+
+  if(!fn.isEmpty()) {
+    loadOverlay(fn);
+
+    /*
+     * set menu items to appropriate states after image has been 
+     * loaded, as they were set to some
+     * states, initially, when no images were loaded
+     */
+    setFileMenuItemsState();
+    setViewMenuItemsState();
+  }
 }
 
 void ApplicationWindow::fileOpen152(void)
@@ -502,8 +613,18 @@ void ApplicationWindow::fileOpen152(void)
 					  "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					  this ));
 
-  if(!fn.isEmpty())
-    loadFile(fn);
+  if(!fn.isEmpty()) {
+    if( loadFile(fn) )
+      viewOrthographic();
+
+    /*
+     * set menu items to appropriate states after image has been 
+     * loaded, as they were set to some
+     * states, initially, when no images were loaded
+     */
+    setFileMenuItemsState();
+    setViewMenuItemsState();
+  }
 }
 
 void ApplicationWindow::fileAdd152(void)
@@ -512,8 +633,17 @@ void ApplicationWindow::fileAdd152(void)
 					  "Image files (*.hdr *.hdr.gz *.nii *.nii.gz)", 
 					  this ));
 
-  if(!fn.isEmpty())
+  if(!fn.isEmpty()) {
     loadOverlay(fn);
+
+    /*
+     * set menu items to appropriate states after image has been 
+     * loaded, as they were set to some
+     * states, initially, when no images were loaded
+     */
+    setFileMenuItemsState();
+    setViewMenuItemsState();
+  }
 }
 
 void ApplicationWindow::buildMenus()
@@ -573,8 +703,7 @@ void ApplicationWindow::update(const Cursor::Handle& c)
 
 void ApplicationWindow::fileSaveAs()
 {
-  ViewWidget *view = (ViewWidget*)m_ws->activeWindow();
-  OverlayList::Handle ol = view->getOverlayList();
+  OverlayList::Handle ol = activeOverlayList();
   QString fn;
 	
   if(!ol)
@@ -646,8 +775,7 @@ void ApplicationWindow::fileSaveAs()
 void ApplicationWindow::fileRemove()
 {  
   
- ViewWidget* view = (ViewWidget*)m_ws->activeWindow();
- OverlayList::Handle ol = view->getOverlayList();
+ OverlayList::Handle ol = activeOverlayList();
  if(!ol)
    {
      QMessageBox::warning(this, "FSLView",
@@ -684,28 +812,19 @@ bool ApplicationWindow::loadOverlay(const QString & absFilePath)
     QFileInfo fi(absFilePath);
     
     removeExtensions(fn);
+
     if ( !fn.isEmpty() && checkFilesExist(fn,false) ) 
       {
         QApplication::setOverrideCursor(Qt::waitCursor);
-        emit message( QString("Loading.... %1").arg(fn), 0);
+        emit message( QString("Loading.... %1").arg(fn), 5000);
+	qApp->processEvents();
 
         Image::Handle overlay = Image::load((const char *)fn);
-        QApplication::restoreOverrideCursor();
 
         if(m_imageGroup->getMainImage()->getInfo()->isCompatible(overlay->getInfo()))
           {
             m_imageGroup->addOverlay( overlay );
-
-// 	    LookUpTable::Handle lut;
-// 	    // Choose lut in image file
-// 	    if(!overlay->getInfo()->inqLutName().empty())
-// 	      lut = m_imageGroup->getLut(overlay->getInfo()->inqLutName());
-// 	    // look for "stat/mask" in the filename and choose colour lut if true
-// 	    if ( overlay->getInfo()->isStatImage() || overlay->getInfo()->isMaskImage() )
-// 	      {
-// 		if(!lut) { lut = m_imageGroup->getNextLut(); }
-// 	      }
-// 	    activeOverlayList()->setLookUpTable(lut);
+	    m_cursor->setVMax(overlay->getInfo()->inqNumVolumes());
           }
         else
           {
@@ -714,8 +833,10 @@ bool ApplicationWindow::loadOverlay(const QString & absFilePath)
 				  "All overlays <b>must</b> have same dimensions as the base image!");
             emit message( "Loading aborted", 2000 );
 	    status = false;
-          }        
+          }
         
+	QApplication::restoreOverrideCursor();
+
         if(checkForDuplicates(fn))
         {
           QMessageBox::warning(this,"FSLView",
@@ -748,6 +869,8 @@ bool ApplicationWindow::loadOverlay(const QString & absFilePath)
       catchFileError(f);
     }
 
+  setFileMenuItemsState();
+
   return status;
 }
 
@@ -771,8 +894,8 @@ void ApplicationWindow::addLookUpTable()
 void ApplicationWindow::fileCreateMask()
 {
  TRACKER("ApplicationWindow::createMask");      
- ViewWidget* view = (ViewWidget*)m_ws->activeWindow();
- OverlayList::Handle ol = view->getOverlayList();
+ OverlayList::Handle ol = activeOverlayList();
+
  if(!ol)
    {
      QMessageBox::warning(this,
@@ -782,7 +905,7 @@ void ApplicationWindow::fileCreateMask()
  else
   {
     Image::Handle mainImg = ol->getMainImage();
-    Image::Handle image = ol->inqActiveImage();
+    Image::Handle image = ol->inqActiveImage(), ci;
     
     if(!isValidImage(image))
       {
@@ -811,20 +934,24 @@ void ApplicationWindow::fileCreateMask()
         if(!m_properties->inqAskCreate4dMask())
           cd->exec();
         if(cd->m_create4dMask->isChecked())
-          m_imageGroup->addOverlay(image->cloneStructure());
+          ci = image->cloneStructure();
         else
-          m_imageGroup->addOverlay(image->clone3dStructure());
+          ci = image->clone3dStructure();
         m_properties->setCreate4dMask(cd->m_create4dMask->isChecked());
         m_properties->setAskCreate4dMask(cd->m_dontAsk->isChecked());
       }
       else
       {
-        m_imageGroup->addOverlay(image->clone3dStructure());
+        ci = image->clone3dStructure();
       }
 
-      //ol->getActiveMetaImage()->getDs()->setLookUpTable(m_imageGroup->getLut(0));
-      emit message( QString("Created new mask: %1-mask")
-                    .arg(image->getInfo()->inqImageName().c_str()), 2000 );
+      m_imageGroup->addOverlay(ci);
+
+      MetaImage::Handle cmi = ol->getMetaImage(ci);
+      cmi->getDs()->setLookUpTable(LookUpTable::redYellow());
+
+      emit message( QString("Created new mask: %1")
+                    .arg(ci->getInfo()->inqImageName().c_str()), 2000 );
       /**
       needed for the first time execution. Even though redundant after wards, no side affect.
       **/
@@ -836,7 +963,7 @@ void ApplicationWindow::fileCreateMask()
 
 void ApplicationWindow::viewOrthographic()
 {  
-  ViewWidget* view = new OrthoWidget(m_ws,m_imageGroup,
+  ViewWidget* view = new OrthoWidget(m_ws, m_imageGroup,
                                      copyActiveOverlayList(), m_cursor);
 
   connect( view, SIGNAL(message(const QString&, int)), 
@@ -845,17 +972,22 @@ void ApplicationWindow::viewOrthographic()
            this, SLOT(addLookUpTable()));
   connect( view, SIGNAL(windowClose(QCloseEvent*)),
            this, SLOT(childWindowClose(QCloseEvent*)));
+
+  connect( view, SIGNAL(overlayEvent()),
+           this, SLOT(menusUpdate()) );
+
   view->setCaption("Ortho view");
 
   view->resize(580,500);
 
-  viewShow(view);  
+  viewShow(view);
+  m_cursor->repaint();
 }
 
 void ApplicationWindow::viewLightbox()
 {
   ViewWidget* view = new LightboxWidget(m_ws, m_imageGroup,
-                                        copyActiveOverlayList(),m_cursor); 
+                                        copyActiveOverlayList(), m_cursor); 
 
   connect( view, SIGNAL(message(const QString&, int)), 
            this, SIGNAL(message(const QString&, int)));   
@@ -863,18 +995,22 @@ void ApplicationWindow::viewLightbox()
            this, SLOT(addLookUpTable()));  
   connect( view, SIGNAL(windowClose(QCloseEvent*)),
            this, SLOT(childWindowClose(QCloseEvent*)));
+
+  connect( view, SIGNAL(overlayEvent()),
+           this, SLOT(menusUpdate()) );
+
   view->setCaption("Lightbox view");  
 
   view->resize(580,500);
 
   viewShow(view);
+  m_cursor->repaint();
 }
 
 void ApplicationWindow::viewSingle()
 {
   ViewWidget* view = new SingleWidget(m_ws, m_imageGroup,
-                                     copyActiveOverlayList(),
-                                     m_cursor); 
+                                     copyActiveOverlayList(), m_cursor); 
 
   connect( view, SIGNAL(message(const QString&, int)), 
            this, SIGNAL(message(const QString&, int)) );   
@@ -882,6 +1018,10 @@ void ApplicationWindow::viewSingle()
            this, SLOT(addLookUpTable()));  
   connect( view, SIGNAL(windowClose(QCloseEvent*)),
            this, SLOT(childWindowClose(QCloseEvent*)));
+
+  connect( view, SIGNAL(overlayEvent()),
+           this, SLOT(menusUpdate()) );
+
   view->setCaption("Single view");  
 
   view->resize(210,345);
@@ -901,11 +1041,16 @@ void ApplicationWindow::view3d()
            this, SLOT(addLookUpTable()));  
   connect( view, SIGNAL(windowClose(QCloseEvent*)),
            this, SLOT(childWindowClose(QCloseEvent*)));
+
+  connect( view, SIGNAL(overlayEvent()),
+           this, SLOT(menusUpdate()) );
+
   view->setCaption("3D view");  
 
   view->resize(210,345);
 
   viewShow(view);  
+  m_cursor->repaint();
 }
 
 void ApplicationWindow::viewClusterBrowser()
@@ -931,8 +1076,7 @@ void ApplicationWindow::viewTimeseries()
 {
   if(m_imageGroup.use_count())
   {  
-    ViewWidget *view = (ViewWidget*)m_ws->activeWindow();
-    OverlayList::Handle ol = view->getOverlayList();
+    OverlayList::Handle ol = activeOverlayList();
     
     if(ol)
     {
@@ -999,16 +1143,27 @@ bool ApplicationWindow::checkAbsFilePath(const QString & absFilePath,
 OverlayList::Handle ApplicationWindow::activeOverlayList()
 {
   OverlayList::Handle ol;
-  ViewWidget* view = (ViewWidget*)m_ws->activeWindow();
 
-  if (!windowListEmpty())ol = view->getOverlayList();
+  ol = m_masterOverlayList;
+
+  if (!windowListEmpty()) {
+    ViewWidget* view = dynamic_cast<ViewWidget*>(m_ws->activeWindow());
+    if(view)
+      ol = view->getOverlayList();
+  }
+
+  if (!ol && m_imageGroup ) {
+    ol = OverlayList::create(m_imageGroup);
+    m_masterOverlayList = ol;
+  }
+
   return ol;
 }
 
 OverlayList::Handle ApplicationWindow::copyActiveOverlayList()
 {
   OverlayList::Handle null;
-  OverlayList::Handle ol = activeOverlayList();
+  OverlayList::Handle ol(activeOverlayList());
   
   if(ol) {return ol->clone();}
   else   {return null;}
@@ -1020,7 +1175,7 @@ void ApplicationWindow::displayMessage(const QString & msg, int time)
   else            statusBar()->message( msg, time );
 }
 
-void ApplicationWindow::viewShow(ViewWidget* v)
+void ApplicationWindow::viewShow(QWidget* v)
 {
   if(windowListEmpty())
     { 
@@ -1067,7 +1222,8 @@ bool ApplicationWindow::tarnishCheck()
   if(m_imageGroup->inqTarnished())
     {
          switch(QMessageBox::warning( this,
-				      "FSLView", QString("Continuing this action will lose unsaved data."),
+				      "FSLView", 
+				      QString("Continuing this action will lose unsaved data."),
 				      "Cancel","OK","",0,0))
           {
           case 0:result = false;break;
@@ -1087,20 +1243,23 @@ void ApplicationWindow::childWindowClose(QCloseEvent* e)
   else
     {
       if(tarnishCheck())e->accept();
-      // schedule a menu item check till the child window is actually closed by the application.
-      QTimer::singleShot(1, this, SLOT(setMenuItems_NoImages()));
     }
+  // schedule a menu item check till the child window is actually closed by the application.
+  QTimer::singleShot(1, this, SLOT(setMenuItems_NoImages()));
 }
 
 void ApplicationWindow::closeEvent(QCloseEvent* e)
 {
+  Preferences::getInstance()->setGeometry(geometry());
+
   if(windowListEmpty())
     {
       e->accept();
     }
   else
     {
-      if(tarnishCheck())e->accept();
+      if(tarnishCheck())
+	e->accept();
     }
 }
 
@@ -1145,20 +1304,13 @@ bool ApplicationWindow::checkForDuplicates(const QString & fn)
   return (FslCheckForMultipleFileNames(fn.ascii())>0);
 }
 
-void ApplicationWindow::loadFeat(QString &fn)
+void ApplicationWindow::loadFeat(const QString &fn)
 {
   QFileInfo  fi(fn);
   
   try {
     m_modelFit = ModelFit::create(fi.dirPath(true));
   
-    Image::Handle image = m_imageGroup->getMainImage();
-  
-    TimeSeriesWidget* timeseries = new TimeSeriesWidget(m_ws, image, m_cursor, m_modelFit);
-    connect( timeseries, SIGNAL(windowClose(QCloseEvent*)), this, SLOT(childWindowClose(QCloseEvent*)));
-    timeseries->setCaption("Feat data");
-    timeseries->resize(250,250);
-    viewShow(timeseries);
     emit message("*File Opened is a FEAT analysis Directory*", 2000);
   } catch (std::ios::failure& e) {
     QMessageBox::warning(this, "Attempting to load FEAT model", e.what());
