@@ -17,27 +17,23 @@ using namespace std;
 #include <qapplication.h>
 
 #include "assistantclient.h"
+#include "preferences.h"
 
 AssistantClient* AssistantClient::m_instance=0;
 
 AssistantClient* AssistantClient::getInstance()
 {
   if(!m_instance) {
-    QString path( QString(getenv("QTDIR")) + QString("/bin") );
+    QString path( Preferences::getInstance()->inqAssistantPath() );
     m_instance = new AssistantClient(path);
   }
-//   if(!m_instance->isOpen()) {
-//     m_instance->openAssistant();
-//     qApp->processEvents();
-//   }
   return m_instance;
 }
 
 AssistantClient::AssistantClient(const QString& path):
   QAssistantClient( path, qApp->mainWidget())
 {
-  QString fsldir(getenv("FSLDIR"));
-  m_docPath = fsldir + QString("/doc/fslview");
+  m_docPath = Preferences::getInstance()->inqFSLDir() + QString("/doc/fslview");
   QStringList args;
 
   args << "-profile" << QString("%1/fslview.adp").arg(m_docPath);
