@@ -17,6 +17,7 @@
 #include <boost/shared_ptr.hpp>
 
 #include <qsettings.h>
+#include <qrect.h>
 
 class Preferences: public QSettings
 {
@@ -27,12 +28,15 @@ public:
   std::string inqMni152() const;
   std::string inqAssistantPath() const;
   std::string inqAtlasPath() const;
+  QRect inqGeometry(int, int) const;
+
   std::vector<std::string> inqAtlasPathElements() const;
 
   void setFSLDir(const std::string&);
   void setMni152(const std::string&);
   void setAssistantPath(const std::string&);
   void setAtlasPath(const std::string&);
+  void setGeometry(const QRect&);
 
   static Handle getInstance();
 
