@@ -8,7 +8,7 @@
 
 
 /****************************************************************************
-** $Id: slicewidget.cpp,v 1.201.4.1 2007/08/09 10:25:59 flitney Exp $
+** $Id: slicewidget.cpp,v 1.201.4.7 2009/04/23 10:29:13 flitney Exp $
 **
 ** Copyright (C) 2002 University of Oxford.  All rights reserved.
 **
@@ -98,15 +98,21 @@ struct Attach
 //! @param u List of shapes drawn in mask mode. Used for the undo functionality
 //!
 SliceWidget::SliceWidget(QWidget* parent, const char *name, Orientation orient, 
-			 Cursor::Handle c, OverlayList::Handle l, DrawSettings::Handle d, 
-			 std::list<Shape::Handle>& u): 
+			 Cursor::Handle c, OverlayList::Handle l, 
+			 DrawSettings::Handle d, 
+			 std::list<Shape::Handle>& u,
+			 const ViewOptions& vo): 
   QWidget(parent, name),
-  m_sliceIsFixed(false), m_updatesEnabled(true), m_crossHairsOn(true),m_imagesEnabled(true), 
+  m_sliceIsFixed(false), m_updatesEnabled(true), m_crossHairsOn(true),
+  m_imagesEnabled(true), 
   m_slice(0), m_noSliceSet(true),m_volume(0), m_cursor(c),
   m_zoom(1.0),m_origX(0),m_origY(0),m_scaleX(1.0),m_scaleY(1.0),
   m_overlayList(l), m_drawSettings(d),m_undoList(u),
-  m_orient(orient),m_mode(None),m_zooming(false),m_trueScale(true),m_forceRender(false), 
-  m_imageBuffersValid(false),m_displayPixmapValid(false),m_displayBufferValid(false)
+  m_orient(orient),m_mode(None),m_zooming(false),m_trueScale(true),
+  m_forceRender(false), 
+  m_imageBuffersValid(false),m_displayPixmapValid(false),
+  m_displayBufferValid(false),
+  m_opts(vo)
 {
   TRACKER("SliceWidget::SliceWidget");  
 
@@ -252,6 +258,15 @@ void SliceWidget::enableUpdates(bool enabled)
   m_updatesEnabled = enabled;
 }
 
+QPixmap SliceWidget::getPixmap() const
+{
+  QPixmap pm(size());
+
+  bitBlt(&pm,0,0,this);
+
+  return pm;
+}
+
 void SliceWidget::paintEvent(QPaintEvent*)
 {
   if(!m_updatesEnabled) { m_imagesEnabled = true; return; }
@@ -263,7 +278,7 @@ void SliceWidget::paintEvent(QPaintEvent*)
   CHECKPOINT();
   QPixmap pm(size());
 
-  if(!m_imagesEnabled){bitBlt(&pm,0,0,this);}
+  if(!m_imagesEnabled){bitBlt(&pm,0,0,this);} // Why!?
   else{pm.fill( black );}
 
   m_paint.begin(&pm,this);
@@ -332,6 +347,8 @@ void SliceWidget::paintEvent(QPaintEvent*)
 //    else m_paint.setBrush(QColor(255, 0, 0));
 //    m_paint.drawRoundRect(m_viewRect->left(),m_viewRect->top(),10, 10);
   
+  m_paint.setPen(QColor(128, 128, 128));
+
   if(m_crossHairsOn)
     {
       if(m_mode == Masking)
@@ -348,11 +365,71 @@ void SliceWidget::paintEvent(QPaintEvent*)
   m_forceRender = false;
   m_imagesEnabled = true; 
 
+  if(m_opts.inqShowSliceLabels())
+    {
+      QFont font = m_paint.font();
+      font.setStyleHint(QFont::SansSerif, 
+			QFont::NoAntialias);
+      font.setPointSize(12);
+      m_paint.setPen(QColor(255, 255, 255));
+      //m_paint.setFont(font);
+      m_paint.setViewport(geometry());
+      m_paint.setClipping(false);
+      m_paint.setWindow(geometry());
+      m_paint.drawText(1, 10, inqLocationText());
+    }
+
   m_paint.end();
   
   bitBlt(this, 0, 0, &pm);
 }
 
+QString AxialWidget::inqLocationText() const
+{
+  QString str;
+  if(m_opts.inqUnitsAreVoxels())
+    str = QString("z=%1").arg(m_slice);
+  else {
+    float x(0), y(0), z(0);
+    ImageInfo::Handle im_info(m_overlayList->getActiveMetaImage()->getInfo());
+
+    im_info->voxToMMCoord(0, 0, m_slice, x, y, z);
+    str = QString("z=%1 mm").arg(z);
+  }
+  return str;
+}
+
+QString SagittalWidget::inqLocationText() const
+{
+  QString str;
+  if(m_opts.inqUnitsAreVoxels())
+    str = QString("x=%1").arg(m_slice);
+  else {
+    float x(0), y(0), z(0);
+    int radiogX(m_slice);
+    ImageInfo::Handle im_info(m_overlayList->getActiveMetaImage()->getInfo());
+    if(!im_info->isStoredRadiological())
+      radiogX = im_info->inqX()-1-radiogX;
+    im_info->voxToMMCoord(radiogX, 0, 0, x, y, z);
+    str = QString("x=%1 mm").arg(x);
+  }
+  return str;
+}
+
+QString CoronalWidget::inqLocationText() const
+{
+  QString str;
+  if(m_opts.inqUnitsAreVoxels())
+    str = QString("y=%1").arg(m_slice);
+  else {
+    float x(0), y(0), z(0);
+    ImageInfo::Handle im_info(m_overlayList->getActiveMetaImage()->getInfo());
+    im_info->voxToMMCoord(0, m_slice, 0, x, y, z);
+    str = QString("y=%1 mm").arg(y);
+  }
+  return str;
+}
+
 void SliceWidget::paintGraphics()
 {
   TRACKER("SliceWidget::paintGraphics()");
@@ -477,7 +554,7 @@ void SliceWidget::update(const Cursor::Handle& c)
 
   if(c->inqRepaint()){m_forceRender = true;invalidateImageBuffers();}
  
-  setImageCursor(c->inqX(), c->inqY(), c->inqZ(),c->inqV());
+  setImageCursor(c->inqX(), c->inqY(), c->inqZ(), c->inqV());
 }
 
 //! @brief BriCon objects update the SliceWidget via this method
@@ -727,6 +804,8 @@ void SliceWidget::commitGraphics()
       if(m_undoList.size() > 20) m_undoList.pop_front();
        
       m_shape->commit();
+
+      mi->getInfo()->setTarnished(true);
     }
  
      m_cursor->repaint();
@@ -924,7 +1003,7 @@ void SliceWidget::renderBuffer()
 	  ColorRGBAHandle buffer(bufferVolume(mi));
 
 	  LookUpTable::Handle slut(mi->getDs()->inqSecondaryLookUpTable());
-	  if(slut) {
+	  if(mi->getDs()->inqUseSecondaryLookUpTable()) {
 	    MetaImage::Handle si(mi->clone());
 	    BriCon::Handle    sb(si->getDs()->inqBriCon());
 	    sb->setRange(-(sb->inqMin()), -(sb->inqMax()));
@@ -1140,15 +1219,15 @@ void SagittalWidget::setImageCursor(int x, int y, int z, int v)
 //! crosshairs of the other slices)
 void SagittalWidget::drawCrossHairLines(const Cursor::Handle c,int slice)
 { 
-  if(c->inqX() == slice)
+  if(c->inqX() == slice) {
+    m_paint.setRasterOp(Qt::XorROP);
     m_paint.setPen( QColor(0,255,0));
-  else 
-    m_paint.setPen( QColor(0,128,0));
-  
-  m_paint.setRasterOp(Qt::XorROP);
-  m_paint.drawLine((c->inqY()*2)+1,0,(c->inqY()*2)+1,inqHeight()*2);
-  m_paint.drawLine(0,(c->inqZ()*2)+1,inqWidth()*2,(c->inqZ()*2)+1);
-  m_paint.setRasterOp(Qt::CopyROP);
+    if (m_opts.inqShowCursorGap())
+      drawBrokenCrossHairLines( (c->inqY()*2)+1, (c->inqZ()*2)+1 );
+    else
+      drawSimpleCrossHairLines( (c->inqY()*2)+1, (c->inqZ()*2)+1 );
+    m_paint.setRasterOp(Qt::CopyROP);
+  }
 }
 
 void SagittalWidget::cursorEvent(int x, int y)
@@ -1193,7 +1272,7 @@ ColorRGBAHandle SagittalWidget::bufferVolume(MetaImage::Handle mi)
 {
   TRACKER("SagittalWidget::bufferVolume");
   CHECKPOINT();
-  return ImageBuffer::sagittalBuffer(mi,m_slice,m_volume);
+  return ImageBuffer::sagittalBuffer(mi,m_slice,mi->getDs()->inqCurrentVolume());
 }
 
 void SagittalWidget::setCursorSlice(short s)
@@ -1300,7 +1379,31 @@ ColorRGBAHandle AxialWidget::bufferVolume(MetaImage::Handle mi)
 {
   TRACKER("AxialWidget::bufferVolume");
   CHECKPOINT();
-  return ImageBuffer::axialBuffer(mi,m_slice,m_volume);
+  return ImageBuffer::axialBuffer(mi,m_slice,mi->getDs()->inqCurrentVolume());
+}
+
+void SliceWidget::drawSimpleCrossHairLines(int x, int y)
+{
+  int h = inqHeight() * 2;
+  int w = inqWidth() * 2;
+
+  m_paint.drawLine(x, 0, x, h);
+  m_paint.drawLine(0, y, w, y);
+}
+
+void SliceWidget::drawBrokenCrossHairLines(int x, int y)
+{
+  int gapsz = m_opts.inqCursorGapSize();
+  int h = inqHeight() * 2;
+  int w = inqWidth() * 2;
+
+  // vertical bar
+  m_paint.drawLine( x, 0,         x, y - gapsz );
+  m_paint.drawLine( x, y + gapsz, x, h         );
+
+  // horizontal bar
+  m_paint.drawLine( 0,         y, x - gapsz, y );
+  m_paint.drawLine( x + gapsz, y, w,         y );
 }
 
 //! @brief Renders the cross hairs.
@@ -1310,15 +1413,15 @@ ColorRGBAHandle AxialWidget::bufferVolume(MetaImage::Handle mi)
 //! crosshairs of the other slices)
 void AxialWidget::drawCrossHairLines(const Cursor::Handle c,int slice)
 {  
-   if(c->inqZ() == slice)
-   m_paint.setPen( QColor(0,255,0));
-   else 
-   m_paint.setPen( QColor(0,128,0));
-
-  m_paint.setRasterOp(Qt::XorROP);
-  m_paint.drawLine((c->inqX()*2)+1,0,(c->inqX()*2)+1,inqHeight()*2);
-  m_paint.drawLine(0,(c->inqY()*2)+1,inqWidth()*2,(c->inqY()*2)+1);
-  m_paint.setRasterOp(Qt::CopyROP);
+  if(c->inqZ() == slice) {
+    m_paint.setRasterOp(Qt::XorROP);
+    m_paint.setPen( QColor(0,255,0));
+    if (m_opts.inqShowCursorGap())
+      drawBrokenCrossHairLines( (c->inqX()*2)+1, (c->inqY()*2)+1 );
+    else
+      drawSimpleCrossHairLines( (c->inqX()*2)+1, (c->inqY()*2)+1 );
+    m_paint.setRasterOp(Qt::CopyROP);
+  }
 }
 
 void AxialWidget::moveCursor(short dx, short dy)
@@ -1397,15 +1500,15 @@ void AxialWidget::drawDtiLines()
 //! crosshairs of the other slices)
 void CoronalWidget::drawCrossHairLines(const Cursor::Handle c,int slice)
 { 
-  if(c->inqY() == slice)
+  if(c->inqY() == slice) {
+    m_paint.setRasterOp(Qt::XorROP);
     m_paint.setPen( QColor(0,255,0));
-  else 
-    m_paint.setPen( QColor(0,128,0));
-  
-  m_paint.setRasterOp(Qt::XorROP);
-  m_paint.drawLine((c->inqX()*2)+1,0,(c->inqX()*2)+1,inqHeight()*2);
-  m_paint.drawLine(0,(c->inqZ()*2)+1,inqWidth()*2,(c->inqZ()*2)+1);
-  m_paint.setRasterOp(Qt::CopyROP);
+    if (m_opts.inqShowCursorGap())
+      drawBrokenCrossHairLines( (c->inqX()*2)+1, (c->inqZ()*2)+1 );
+    else
+      drawSimpleCrossHairLines( (c->inqX()*2)+1, (c->inqZ()*2)+1 );
+    m_paint.setRasterOp(Qt::CopyROP);
+  }
 }
 
 void CoronalWidget::cursorEvent(int x, int y)
@@ -1449,7 +1552,7 @@ ColorRGBAHandle CoronalWidget::bufferVolume(MetaImage::Handle mi)
 {
   TRACKER("CoronalWidget::bufferVolume");
   CHECKPOINT();
-  return ImageBuffer::coronalBuffer(mi,m_slice,m_volume);
+  return ImageBuffer::coronalBuffer(mi,m_slice,mi->getDs()->inqCurrentVolume());
 }
 
 void CoronalWidget::moveCursor(short dx, short dy)
