@@ -22,6 +22,7 @@
 
 #include "vtkwidget.h"
 #include "maintoolbar.h"
+#include "modetoolbar.h"
 #include "metaimage.h"
 
 //#define DEBUGGING
@@ -57,7 +58,7 @@
 #include <vtkImageThreshold.h>
 #include <vtkCellDataToPointData.h>
 
-#include <vtkImageReslice.h>
+//#include <vtkImageReslice.h>
 #include <vtkProperty.h>
 #include <vtkVolumeProperty.h>
 #include <vtkPiecewiseFunction.h>
@@ -102,7 +103,7 @@
 #include "meshoptionsdialog.h"
 using namespace std;
 
-class VTKLookUpTable
+class LookUpTableFactory
 {
 public:
   static vtkLookupTable* convert(LookUpTable::Handle lh)
@@ -220,12 +221,17 @@ private:
 };
 
 VTKProperties::VTKProperties(): 
-  m_upperThreshold(32000), m_lowerThreshold(80), 
+  m_upperThreshold(32000), 
+  m_lowerThreshold(80), 
   m_mcThreshold(0.999),
   m_interpMode(VTK_GOURAUD),
   m_iterations(5),
   m_relaxationFactor(0.2), 
-  m_ambient(0.1), m_diffuse(0.9), m_opacity(1.0), m_specular(0.1), m_specularPower(20),
+  m_ambient(0.1), 
+  m_diffuse(0.9), 
+  m_opacity(1.0),
+  m_specular(0.1),
+  m_specularPower(20),
   m_featureAngle(179.0),
   m_stdDev(0.1), m_radius(1.0),
   m_colorR(0.80), m_colorG(0.80), m_colorB(0.80),
@@ -358,8 +364,8 @@ public:
 	  // 
 	  *ptr++ = im->getVolume(0)->value(ii->inqX() - 1 - x, y, z);
 
-    m_surfLut = VTKLookUpTable::convert(LookUpTable::greyScale());
-    m_imageLut = VTKLookUpTable::convert(LookUpTable::greyScale());
+    m_surfLut = LookUpTableFactory::convert(LookUpTable::greyScale());
+    m_imageLut = LookUpTableFactory::convert(LookUpTable::greyScale());
 
     m_layerRGBA = vtkImageMapToColors::New();
     m_layerRGBA->SetOutputFormatToRGBA();
@@ -442,12 +448,12 @@ public:
     
     if(lh) {
       MESSAGE(std::string("Searching for LUT:") + lh->inqLutName());
-      setImageLut(VTKLookUpTable::convert(lh));
-      setSurfaceLut(VTKLookUpTable::convert(lh));
+      setImageLut(LookUpTableFactory::convert(lh));
+      setSurfaceLut(LookUpTableFactory::convert(lh));
     } else {
       MESSAGE(std::string("Using LUT: GreyScale"));
-      setImageLut(VTKLookUpTable::convert(LookUpTable::greyScale()));
-      setSurfaceLut(VTKLookUpTable::convert(LookUpTable::greyScale()));
+      setImageLut(LookUpTableFactory::convert(LookUpTable::greyScale()));
+      setSurfaceLut(LookUpTableFactory::convert(LookUpTable::greyScale()));
     }
     BriCon::Handle bc(mi->getDs()->inqBriCon());
     m_imageLut->SetRange(bc->inqMin(), bc->inqMax());
@@ -535,12 +541,12 @@ public:
     
     if(lh) {
       MESSAGE(std::string("Searching for LUT:") + lh->inqLutName());
-      setImageLut(VTKLookUpTable::convert(lh));
-      setSurfaceLut(VTKLookUpTable::convert(lh));
+      setImageLut(LookUpTableFactory::convert(lh));
+      setSurfaceLut(LookUpTableFactory::convert(lh));
     } else {
       MESSAGE(std::string("Using LUT: GreyScale"));
-      setImageLut(VTKLookUpTable::convert(LookUpTable::greyScale()));
-      setSurfaceLut(VTKLookUpTable::convert(LookUpTable::greyScale()));
+      setImageLut(LookUpTableFactory::convert(LookUpTable::greyScale()));
+      setSurfaceLut(LookUpTableFactory::convert(LookUpTable::greyScale()));
     }
     BriCon::Handle bc(mi->getDs()->inqBriCon());
     m_imageLut->SetRange(bc->inqMin(), bc->inqMax());
@@ -573,11 +579,11 @@ public:
     mcdecim->BoundaryVertexDeletionOn();
 
     m_smooth->SetInput(mcdecim->GetOutput());
-    m_smooth->SetNumberOfIterations(20);
-    m_smooth->SetFeatureAngle(150);
-    m_smooth->SetFeatureEdgeSmoothing(true);
-    m_smooth->SetBoundarySmoothing(true);
-    m_smooth->SetRelaxationFactor(0.5);
+    m_smooth->SetNumberOfIterations(2);
+//     m_smooth->SetFeatureAngle(150);
+//     m_smooth->SetFeatureEdgeSmoothing(true);
+//     m_smooth->SetBoundarySmoothing(false);
+//     m_smooth->SetRelaxationFactor(0.1);
 
     m_normals->SetInput(m_smooth->GetOutput());
     m_normals->SplittingOn();
@@ -754,6 +760,8 @@ VTKWidget::VTKWidget(QWidget *parent,
   VTKToolbar *vt = new VTKToolbar(tb, m_impl->m_props);
 
   addDockWindow(tb, tr("VTK Rendering Tools"), Top, FALSE);  
+  m_toolbar->hide();
+  m_modebar->hide();
 
   connect(vt->m_printButton,   SIGNAL(clicked()), SLOT(print()));
   connect(vt->m_optionsButton, SIGNAL(clicked()), SLOT(options()));
@@ -765,7 +773,7 @@ VTKWidget::VTKWidget(QWidget *parent,
   ren->SetBackground(0.4, 0.4, 0.4);
   m_vtkwidget->GetRenderWindow()->AddRenderer(ren);
 
-  //  VTKLookUpTable *lut = new VTKLookUpTable();
+  //  LookUpTableFactory *lut = new LookUpTableFactory();
     
   m_impl->m_mainImage = MainImage::Handle(new MainImage(ol->getMainMetaImage(), m_impl->m_props, ren));
   m_impl->m_mainImage->update(ol->getMainMetaImage()->getDs()->inqBriCon().get());
@@ -890,9 +898,9 @@ VTKWidget::VTKWidget(QWidget *parent,
 // 	  LookUpTable::Handle lh(mi->getDs()->inqLookUpTable());
 // 	  vtkLookupTable *thisLut;
 // 	  if(lh)
-// 	    thisLut = VTKLookUpTable::convert(lh);
+// 	    thisLut = LookUpTableFactory::convert(lh);
 // 	  else
-// 	    thisLut = VTKLookUpTable::convert(LookUpTable::greyScale());
+// 	    thisLut = LookUpTableFactory::convert(LookUpTable::greyScale());
 	       
 
 // 	  vtkActor *ellipseActor = vtkActor::New();
@@ -1160,9 +1168,9 @@ void VTKWidget::update(const OverlayList *ol, OverlayListMsg msg)
       LookUpTable::Handle lh(mi->getDs()->inqLookUpTable());
       vtkLookupTable *lut;
       if(lh)
-	lut = VTKLookUpTable::convert(lh);
+	lut = LookUpTableFactory::convert(lh);
       else
-	lut = VTKLookUpTable::convert(LookUpTable::greyScale());
+	lut = LookUpTableFactory::convert(LookUpTable::greyScale());
       po->setImageLut(lut);
       po->setSurfaceLut(lut);
     }
@@ -1237,9 +1245,11 @@ void VTKWidget::options()
       m_impl->m_brainActor->GetProperty()->SetColor(cr, cg, cb);
       if(m_impl->m_props.inqOpacity() != 1.0)
 	m_impl->m_surfMapper->SetInput(m_impl->m_sorter->GetOutput());
-      else
+      else if(m_impl->m_props.inqClipping())
 	m_impl->m_surfMapper->SetInput(m_impl->m_clipper->GetOutput());
-
+      else
+	m_impl->m_surfMapper->SetInput(m_impl->m_mainImage->GetSurface());
+	
       QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
       m_vtkwidget->GetRenderWindow()->Render();
       QApplication::restoreOverrideCursor();
